@@ -17,6 +17,7 @@ from suite_py.commands import delete_qa
 from suite_py.commands import status
 from suite_py.commands import check
 from suite_py.commands import ip
+from suite_py.commands import generator
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.config import Config
 from suite_py.__version__ import __version__
@@ -53,7 +54,7 @@ def main(ctx, project, timeout):
     ctx.ensure_object(dict)
     ctx.obj["project"] = project_name
     ctx.obj["captainhook_timeout"] = timeout  # Might be also None
-    os.chdir(os.path.join(config.load()["user"]["projects_home"], project_name))
+    os.chdir(os.path.join(config.load()["user"]["projects_home"], ctx.obj["project"]))
 
 
 @main.command(
@@ -106,8 +107,9 @@ def cli_create_qa(ctx):
 
 
 @main.command("delete-qa", help="Cancella un QA (integrazione con qainit)")
-def cli_delete_qa():
-    delete_qa.entrypoint()
+@click.pass_context
+def cli_delete_qa(ctx):
+    delete_qa.entrypoint(ctx.obj["project"])
 
 
 @main.command(
@@ -149,3 +151,8 @@ def cli_check(ctx):
 @click.pass_context
 def cli_ip(ctx, environment):
     ip.entrypoint(ctx.obj["project"], environment)
+
+
+@main.command("generator", help="Genera diversi file partendo da dei templates")
+def cli_generator():
+    generator.entrypoint()
