@@ -11,6 +11,8 @@ logger = Logger()
 
 cloudformation = boto3.client("cloudformation", region_name="eu-west-1")
 cloudfront = boto3.client("cloudfront", region_name="eu-west-1")
+ecs = boto3.client("ecs", region_name="eu-west-1")
+ec2 = boto3.client("ec2", region_name="eu-west-1")
 
 
 def update_stack(stack_name, version):
@@ -145,3 +147,78 @@ def update_stacks(stacks_name, version):
                 f"Errore durante l'update dello stack CloudFormation {stack_name}. Contattare i DevOps"
             )
             sys.exit(-1)
+
+
+def get_ecs_services(cluster_name):
+    with Halo(text="Loading services...", spinner="dots", color="magenta"):
+        done = False
+        services = []
+        options = {"cluster": cluster_name, "maxResults": 10}
+        nextToken = None
+
+        while not done:
+            if nextToken:
+                options["nextToken"] = nextToken
+            list_services = ecs.list_services(**options)
+
+            if (
+                "nextToken" in list_services.keys()
+                and list_services["nextToken"] != "null"
+            ):
+                nextToken = list_services["nextToken"]
+            else:
+                done = True
+
+            if not list_services["serviceArns"]:
+                return []
+
+            list_services_description = ecs.describe_services(
+                cluster=cluster_name, services=list_services["serviceArns"]
+            )
+
+            services = services + list_services_description["services"]
+
+        return services
+
+
+def get_ips_from_container_instances(cluster_name, container_instances):
+    instances_id = []
+    ips = []
+
+    container_instances_description = ecs.describe_container_instances(
+        cluster=cluster_name, containerInstances=container_instances
+    )
+
+    for c in container_instances_description["containerInstances"]:
+        instances_id.append(c["ec2InstanceId"])
+
+    instances_description = ec2.describe_instances(InstanceIds=instances_id)
+
+    for reservation in instances_description["Reservations"]:
+        for instance in reservation["Instances"]:
+            ips.append(instance["PrivateIpAddress"])
+
+    return ips
+
+
+def get_container_instances_arn_from_service(cluster_name, service_name):
+    container_instances_arn = []
+    tasks = ecs.list_tasks(
+        cluster=cluster_name, desiredStatus="RUNNING", serviceName=service_name,
+    )["taskArns"]
+
+    tasks_descriptions = ecs.describe_tasks(cluster=cluster_name, tasks=tasks)
+
+    for task in tasks_descriptions["tasks"]:
+        container_instances_arn.append(task["containerInstanceArn"])
+
+    return container_instances_arn
+
+
+def get_ecs_clusters(env):
+    clusters = []
+    list_clusters = ecs.list_clusters()
+    for c in list_clusters["clusterArns"]:
+        if f"-{env}-" in c and "-ci-" not in c:
+            clusters.append(c)
+    return clusters
