@@ -24,8 +24,26 @@ class SlackHandler(metaclass=Singleton):
         channel = config.load()["user"].get(channel_config)
         if channel:
             try:
-                self._client.chat_postMessage(channel=channel, text=text, as_user=True)
+                return self._client.chat_postMessage(
+                    channel=channel, text=text, as_user=True
+                )
             except Exception:
                 logger.warning("Non sono riuscito a inviare il messaggo su Slack")
         else:
             logger.info("Le notifiche su Slack sono disabilitate")
+
+        return None
+
+    def reply_thread(self, channel_config, thread_id, text):
+        channel = config.load()["user"].get(channel_config)
+        if channel:
+            try:
+                return self._client.chat_postMessage(
+                    channel=channel, thread_ts=thread_id, text=text, as_user=True
+                )
+            except Exception:
+                logger.warning("Non sono riuscito a inviare il messaggo su Slack")
+        else:
+            logger.info("Le notifiche su Slack sono disabilitate")
+
+        return None
